@@ -4,13 +4,22 @@ from git import GitCommandError
 from .color_diff import color_diff
 from util import commits_full_list, prompt_for_commit_selection
 
-@click.command()
+@click.command(short_help = "Compare current status with selected commit")
 @click.pass_context
-@click.option('-c', '--commit', help='Hash of commit to compare')
+@click.option('-h', '--hash', 'commit', help='Hash of commit to compare')
 def compare(ctx,commit):
-    '''
-    Compare current status with selected commit
-    '''
+    """
+    Compare current status with selected commit.
+
+    To display a list with all the commits run:
+
+        $ gt compare 
+
+    If you know the hash of the commit you want to compare your repo with, then run
+    
+        $ gt compare --hash  <commitHash>
+
+    """
     #Recover repo from context
     repo = ctx.obj['REPO']
 
